{"": "", "<i class=\\\"fas fa-plus-circle\\\"></i>\\n": "", "Cancel": "Cancelar", "Command": "Comando", "Comment": "Coment\u00e1rio", "Day (month)": "Dia (m\u00eas)", "Day (week)": "Dia (semana)", "Day of the month": "Dia do m\u00eas", "Day of the week": "Dia da semana", "Environment variables": "Vari\u00e1veis de ambiente", "Hour": "Hora", "Jobs": "Tarefas", "Minute": "Minuto", "Modify": "Alterar", "Month": "M\u00eas", "Name": "Nome", "OK": "OK", "Save": "Salvar", "Special": "Especial", "There is no cronjob.": "N\u00e3o h\u00e1 cronjob.", "There is no special task.": "N\u00e3o h\u00e1 nenhuma tarefa especial.", "There is no variables environment set.": "N\u00e3o h\u00e1 nenhum ambiente de vari\u00e1veis definido.", "Value": "Valor", "Cron": "Cron", "normal task": "tarefa normal", "special task": "tarefa especial", "environment variable": "vari\u00e1vel de ambiente", "Do you really want to permanently delete this entry?": "Voc\u00ea realmente quer excluir esta entrada permanentemente?", "Delete": "Excluir", "Crontab successfully saved !": "Crontab salva com sucesso!", "Failed to save crontab": "Falha ao salvar crontab"}