{"": "", "<i class=\\\"fas fa-plus-circle\\\"></i>\\n": "<i class=\\\"fas fa-plus-circle\\\"></i>\\n", "Cancel": "Annuler", "Command": "Commande", "Comment": "Commentaire", "Day (month)": "Jour (mois)", "Day (week)": "Jour (semaine)", "Day of the month": "Jour du mois", "Day of the week": "Jour de la semaine", "Environment variables": "Variables d'environnement", "Hour": "Heure", "Jobs": "T\u00e2ches", "Minute": "Minute", "Modify": "Modifier", "Month": "Mois", "Name": "Nom", "OK": "OK", "Save": "Sauvegarder", "Special": "Sp\u00e9cial", "There is no cronjob.": "Il n'y a pas de t\u00e2che cron.", "There is no special task.": "Il n'y a pas de t\u00e2che sp\u00e9ciale.", "There is no variables environment set.": "Il n'y a pas d'environnement de variables.", "Value": "Valeur", "Cron": "Cron", "normal task": "t\u00e2che normale", "special task": "t\u00e2che sp\u00e9ciale", "environment variable": "variable d'environnement", "Do you really want to permanently delete this entry?": "Souhaitez-vous vraiment supprimer cette entr\u00e9e\u00a0?", "Delete": "Supprimer", "Crontab successfully saved !": "Crontab enregistr\u00e9 avec succ\u00e8s !", "Failed to save crontab": "\u00c9chec de l'enregistrement du crontab"}