{"": "", "<i class=\\\"fas fa-plus-circle\\\"></i>\\n": "", "Cancel": "Avbryt", "Command": "Kommando", "Comment": "Kommentar", "Day (month)": "Dag (m\u00e5nad)", "Day (week)": "Dag (vecka)", "Day of the month": "Dag i m\u00e5naden", "Day of the week": "Veckodag", "Environment variables": "Milj\u00f6variabler", "Hour": "Timme", "Jobs": "Jobb", "Minute": "Minut", "Modify": "\u00c4ndra", "Month": "M\u00e5nad", "Name": "Namn", "OK": "OK", "Save": "Spara", "Special": "Speciell", "There is no cronjob.": "Det finns inget cronjobb.", "There is no special task.": "Det finns ingen speciell uppgift.", "There is no variables environment set.": "Det finns ingen variablermilj\u00f6 satt.", "Value": "V\u00e4rde", "Cron": "Cron", "normal task": "normal uppgift", "special task": "speciell uppgift", "environment variable": "milj\u00f6variabel", "Do you really want to permanently delete this entry?": "Vill du verkligen permanent ta bort denna post?", "Delete": "Ta bort", "Crontab successfully saved !": "Crontab har sparats!", "Failed to save crontab": "Det gick inte att spara crontab"}