{"": "", "<i class=\\\"fas fa-plus-circle\\\"></i>\\n": "", "Cancel": "", "Command": "", "Comment": "", "Day (month)": "", "Day (week)": "", "Day of the month": "", "Day of the week": "", "Environment variables": "", "Hour": "", "Jobs": "", "Minute": "", "Modify": "", "Month": "", "Name": "", "OK": "", "Save": "", "Special": "", "There is no cronjob.": "", "There is no special task.": "", "There is no variables environment set.": "", "Value": "", "Cron": "", "normal task": "", "special task": "", "environment variable": "", "Do you really want to permanently delete this entry?": "", "Delete": "", "Crontab successfully saved !": "", "Failed to save crontab": ""}