{"": "", "<i class=\\\"fas fa-plus-circle\\\"></i>\\n": "", "Cancel": "Anulare", "Command": "Comand\u0103", "Comment": "Comentariu", "Day (month)": "Zi (lun\u0103)", "Day (week)": "Zi (s\u0103pt\u0103m\u00e2n\u0103)", "Day of the month": "Ziua lunii", "Day of the week": "Ziua s\u0103pt\u0103m\u00e2nii", "Environment variables": "Variabile de mediu", "Hour": "Ora", "Jobs": "Joburi", "Minute": "Minut", "Modify": "Modificare", "Month": "Luna", "Name": "Nume", "OK": "OK", "Save": "Salvare", "Special": "Special", "There is no cronjob.": "Nu exist\u0103 joburi.", "There is no special task.": "Nu exist\u0103 sarcini speciale.", "There is no variables environment set.": "Nu exist\u0103 nici o variabil\u0103 de mediu setat\u0103.", "Value": "Valoare", "Cron": "Cron", "normal task": "sarcin\u0103 normal\u0103", "special task": "sarcin\u0103 special\u0103", "environment variable": "variabil\u0103 de mediu", "Do you really want to permanently delete this entry?": "Sunte\u0163i sigur c\u0103 dori\u0163i s\u0103 \u015fterge\u0163i definitiv aceast\u0103 intrare?", "Delete": "\u0218tergere", "Crontab successfully saved !": "Crontab salvat cu succes!", "Failed to save crontab": "Salvarea crontab a e\u0219uat"}