{"": "", "<i class=\\\"fas fa-plus-circle\\\"></i>\\n": "", "Cancel": "Cancelar", "Command": "Comando", "Comment": "Comentario", "Day (month)": "D\u00eda (mes)", "Day (week)": "D\u00eda (semana)", "Day of the month": "D\u00eda del mes", "Day of the week": "D\u00eda de la semana", "Environment variables": "Variables de entorno", "Hour": "Hora", "Jobs": "Trabajos", "Minute": "Minuto", "Modify": "Modificar", "Month": "Mes", "Name": "Nombre", "OK": "OK", "Save": "Guardar", "Special": "Especial", "There is no cronjob.": "No hay cronjob.", "There is no special task.": "No hay tareas especiales.", "There is no variables environment set.": "No se han establecido variabls de entorno.", "Value": "Valor", "Cron": "Cron", "normal task": "Tarea normal", "special task": "Tarea especial", "environment variable": "Variable de entorno", "Do you really want to permanently delete this entry?": "\u00bfQuiere eliminar permanentemente esta entrada?", "Delete": "Eliminar", "Crontab successfully saved !": "Crontab guardado con \u00e9xito !", "Failed to save crontab": "Error al guardar la crontab"}