{"": "", "<i class=\\\"fas fa-plus-circle\\\"></i>\\n": "", "Cancel": "Vazge\u00e7", "Command": "Komut", "Comment": "Yorum", "Day (month)": "G\u00fcn (ay)", "Day (week)": "G\u00fcn (hafta)", "Day of the month": "Ay\u0131n g\u00fcn\u00fc", "Day of the week": "Haftan\u0131n g\u00fcn\u00fc", "Environment variables": "Ortam de\u011fi\u015fkenleri", "Hour": "Saat", "Jobs": "\u0130\u015fler", "Minute": "Dakika", "Modify": "D\u00fczenle", "Month": "Ay", "Name": "\u0130sim", "OK": "Tamam", "Save": "Kaydet", "Special": "\u00d6zel", "There is no cronjob.": "Zamanlanm\u0131\u015f g\u00f6rev yok.", "There is no special task.": "\u00d6zel g\u00f6rev yok.", "There is no variables environment set.": "De\u011fi\u015fken ortam k\u00fcmesi yoktur.", "Value": "De\u011fer", "Cron": "Zamanlama", "normal task": "normal g\u00f6rev", "special task": "\u00f6zel g\u00f6rev", "environment variable": "ortam de\u011fi\u015fkeni", "Do you really want to permanently delete this entry?": "Bu giri\u015fi ger\u00e7ekten kal\u0131c\u0131 olarak silmek istiyor musunuz?", "Delete": "Sil", "Crontab successfully saved !": "Crontab ba\u015far\u0131yla kaydedildi!", "Failed to save crontab": "Crontab kaydedilemedi"}