{"": "", "<i class=\\\"fas fa-plus-circle\\\"></i>\\n": "", "Cancel": "Annulla", "Command": "Comando", "Comment": "Commento", "Day (month)": "Giorni (mese)", "Day (week)": "Giorni (settimana)", "Day of the month": "Giorno del mese", "Day of the week": "Giorno della settimana", "Environment variables": "Variabili ambientali", "Hour": "Ora", "Jobs": "Lavori", "Minute": "Minuto", "Modify": "Modifica", "Month": "Mese", "Name": "Nome", "OK": "OK", "Save": "Salva", "Special": "Speciale", "There is no cronjob.": "Nessun cronjob.", "There is no special task.": "Nessun'attivit\u00e0 speciale.", "There is no variables environment set.": "Nessuna variabile ambientale impostata.", "Value": "Valore", "Cron": "Cron", "normal task": "attivit\u00e0 normale", "special task": "attivit\u00e0 speciale", "environment variable": "variabile ambientale", "Do you really want to permanently delete this entry?": "Sei sicuro di voler eliminare permanentemente questa voce?", "Delete": "Elimina", "Crontab successfully saved !": "Crontab salvata correttamente !", "Failed to save crontab": "Impossibile salvare la crontab"}