{"": "", "<i class=\\\"fas fa-plus-circle\\\"></i>\\n": "", "Cancel": "Anuluj", "Command": "Komenda", "Comment": "Komentarz", "Day (month)": "Dzie\u0144 (miesi\u0105c)", "Day (week)": "Dzie\u0144 (tydzie\u0144)", "Day of the month": "Dzie\u0144 miesi\u0105ca", "Day of the week": "Dzie\u0144 tygodnia", "Environment variables": "Zmienne \u015brodowiskowe", "Hour": "Godzina", "Jobs": "Zadania", "Minute": "Minuta", "Modify": "Modyfikuj", "Month": "Miesi\u0105c", "Name": "Nazwa", "OK": "OK", "Save": "Zapisz", "Special": "Specjalne", "There is no cronjob.": "Brak zadania cron.", "There is no special task.": "Nie ma specjalnego zadania.", "There is no variables environment set.": "Nie ma ustawionych zmiennych.", "Value": "Warto\u015b\u0107", "Cron": "Cron", "normal task": "normalne zadanie", "special task": "specjalne zadanie", "environment variable": "Zmienna \u015brodowiskowa", "Do you really want to permanently delete this entry?": "Czy naprawd\u0119 chcesz trwale usun\u0105\u0107 ten wpis?", "Delete": "Usu\u0144", "Crontab successfully saved !": "Crontab zosta\u0142 pomy\u015blnie zapisany!", "Failed to save crontab": "Nie mo\u017cna by\u0142o zapisa\u0107 crontab"}