{"": "", "<i class=\\\"fas fa-plus-circle\\\"></i>\\n": "<i class=\\\"fas fa-plus-circle\\\"></i>\\n", "Cancel": "Abbrechen", "Command": "Befehl", "Comment": "Kommentar", "Day (month)": "Tag (Monat)", "Day (week)": "Tag (Woche)", "Day of the month": "Tag des Monats", "Day of the week": "Wochentag", "Environment variables": "Umgebungsvariablen", "Hour": "Stunde", "Jobs": "Auftr\u00e4ge", "Minute": "Minute", "Modify": "\u00c4ndern", "Month": "Monat", "Name": "Name", "OK": "OK", "Save": "Speichern", "Special": "Besondere", "There is no cronjob.": "Es gibt keinen Cronjob.", "There is no special task.": "Es gibt keine besondere Aufgabe.", "There is no variables environment set.": "Es gibt keine Umgebungsvariablen.", "Value": "Wert", "Cron": "Cron", "normal task": "normale Aufgabe", "special task": "spezielle Aufgabe", "environment variable": "Umgebungsvariable", "Do you really want to permanently delete this entry?": "Wollen Sie diesen Eintrag wirklich entfernen?", "Delete": "Entfernen", "Crontab successfully saved !": "Crontab erfolgreich gespeichert!", "Failed to save crontab": "Fehler beim Speichern von crontab"}