{"": "", "<i class=\\\"fas fa-plus-circle\\\"></i>\\n": "", "Cancel": "\u53d6\u6d88 ", "Command": "\u547d\u4ee4", "Comment": "\u5907\u6ce8", "Day (month)": "\u5929 (\u6708)", "Day (week)": "\u5929 (\u5468)", "Day of the month": "\u6708\u4efd\u4e2d\u7684\u5929", "Day of the week": "\u6bcf\u5468\u7684\u67d0\u65e5", "Environment variables": "\u73af\u5883\u53d8\u91cf", "Hour": "\u65f6", "Jobs": "\u4efb\u52a1", "Minute": "\u5206\u949f", "Modify": "\u4fee\u6539", "Month": "\u6708", "Name": "\u540d\u79f0", "OK": "\u786e\u5b9a", "Save": "\u4fdd\u5b58", "Special": "\u6742\u9879", "There is no cronjob.": "\u6ca1\u6709\u5b9a\u65f6\u4efb\u52a1", "There is no special task.": "\u6ca1\u6709\u7279\u6b8a\u7684\u4efb\u52a1\u3002", "There is no variables environment set.": "", "Value": "", "Cron": "", "normal task": "", "special task": "", "environment variable": "", "Do you really want to permanently delete this entry?": "", "Delete": "", "Crontab successfully saved !": "", "Failed to save crontab": ""}